pub enum ClientError {
SendError,
RecvError,
}Expand description
Errors occurring when the client is talking to the node.
Variants
SendError
The channel to the node was likely closed and dropped from memory.
RecvError
A channel was dropped before sending its value back.